@@ -851,7 +851,12 @@ def find_repositories_below(path, check_inside=False):
             yield checked
             if not check_inside:
                 continue
-        names = os.listdir(checked)
+        try:
+            names = os.listdir(checked)
+        except OSError:
+            # Things like permission errors (say, on lost+found)
+            # Let's ignorre this, better to process whatever we can
+            names = []
         paths = [checked + '/' + name
                  for name in names if name != '.hg']
         dir_paths = [item
@@ -909,7 +914,12 @@ def command(cmdtable):
     """
     from mercurial import cmdutil, commands
     import inspect
-    command = cmdutil.command(cmdtable)
+    try:
+        from mercurial import registrar
+        command = registrar.command(cmdtable)
+        return command
+    except (ImportError, AttributeError):
+        command = cmdutil.command(cmdtable)
     spec = inspect.getargspec(command)
     if 'norepo' in spec[0]:
         # Looks like modern mercurial with correct api, keeping
